Module blaxel.core.sandbox.client.models.process_request_env
============================================================

Classes
-------

`ProcessRequestEnv()`
:   Example:
        {'{"PORT"': ' "3000"}'}
    
    Method generated by attrs for class ProcessRequestEnv.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, str]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :